"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePlayback = void 0;
const react_1 = require("react");
const reducer_1 = require("./state/reducer");
const state_1 = require("./state/state");
const actions_1 = require("./state/actions");
const helper_1 = require("./helper");
exports.usePlayback = (frames) => {
    const [state, dispatch] = react_1.useReducer(reducer_1.createReducer(), undefined, () => state_1.getDefaultState(frames));
    const [frame, setFrame] = react_1.useState(frames.length ? frames[0] : null);
    react_1.useEffect(() => {
        if (state.frames.length === 0) {
            setFrame(null);
        }
        else {
            setFrame(state.frames[state.cursor]);
        }
    }, [state.cursor, state.frames]);
    react_1.useEffect(() => {
        if (state.playing) {
            const frameDuration = Math.min(1000 / state.fpsLimit, state.duration ? state.duration / state.frames.length : Infinity) / 2;
            const elapsedTime = Date.now() - state.startTime;
            const theoriticalTime = frameDuration * (state.cursor - state.startCursor);
            (() => __awaiter(void 0, void 0, void 0, function* () {
                if (elapsedTime < theoriticalTime)
                    yield helper_1.wait(frameDuration);
                dispatch(actions_1.getNextFrame());
            }))();
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [state.playing, state.cursor]);
    return [
        frame,
        {
            playing: state.playing,
            getPrev: () => dispatch(actions_1.getPreviousFrame()),
            getNext: () => dispatch(actions_1.getNextFrame()),
            playPB: () => dispatch(actions_1.play()),
            pausePB: () => dispatch(actions_1.pause()),
            resetPB: () => dispatch(actions_1.reset()),
            setFPS: (fps) => dispatch(actions_1.updateFps(fps)),
            setDuration: (duration) => dispatch(actions_1.updateDuration(duration)),
            clearPB: () => dispatch(actions_1.clearFrames()),
            pushFrames: (frames) => dispatch(actions_1.pushFrames(frames)),
        },
    ];
};
