"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePlayback = void 0;
const react_1 = require("react");
const reducer_1 = require("./state/reducer");
const state_1 = require("./state/state");
const actions_1 = require("./state/actions");
function usePlayback(frames = [], duration = 0, autoplay = false) {
    const [state, dispatch] = react_1.useReducer(reducer_1.createReducer(), undefined, () => state_1.getDefaultState(frames, duration > 0 ? duration : 0, autoplay));
    react_1.useEffect(() => {
        if (!state.playing)
            return;
        const frameDuration = state.duration / state.frames.length;
        let interval = setInterval(() => {
            const playTime = Date.now() - state.startTime;
            const newCursor = Math.ceil(playTime / frameDuration) + state.startCursor;
            dispatch(actions_1.setCursor(newCursor));
        });
        return () => clearInterval(interval);
    }, [state.playing, state.cursor]);
    return [
        state.frames[state.cursor] || null,
        state.playing,
        react_1.useMemo(() => ({
            clear: () => dispatch(actions_1.clear()),
            load: (frames, duration, autoplay = false) => {
                if (frames.length && duration > 0)
                    dispatch(actions_1.load([frames, duration, autoplay]));
                else
                    throw new Error("frames can't be empty and duration must be a positive number");
            },
            getPrevFrame: () => dispatch(actions_1.getPreviousFrame()),
            getNextFrame: () => dispatch(actions_1.getNextFrame()),
            play: () => dispatch(actions_1.play()),
            pause: () => dispatch(actions_1.pause()),
            reset: () => dispatch(actions_1.reset()),
            setDuration: (duration) => dispatch(actions_1.updateDuration(duration)),
            setLoop: (isLoop) => dispatch(actions_1.setLoop(isLoop)),
        }), [
            dispatch,
            actions_1.clear,
            actions_1.load,
            actions_1.getPreviousFrame,
            actions_1.getNextFrame,
            actions_1.play,
            actions_1.pause,
            actions_1.reset,
            actions_1.updateDuration,
            actions_1.setLoop,
        ]),
        state.loop,
    ];
}
exports.usePlayback = usePlayback;
