"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createReducer = void 0;
const immer_1 = require("immer");
const actions_1 = require("./actions");
exports.createReducer = () => (state, action) => {
    let newState = state;
    switch (action.type) {
        case actions_1.ActionType.PLAY:
            if (!state.playing)
                newState = Object.assign(Object.assign({}, newState), { playing: true, startCursor: state.cursor, startTime: Date.now() });
            break;
        case actions_1.ActionType.PAUSE:
            if (state.playing)
                newState = Object.assign(Object.assign({}, newState), { playing: false, startTime: null, startCursor: null });
            break;
        case actions_1.ActionType.RESET:
            newState = Object.assign(Object.assign({}, newState), { playing: false, cursor: 0, startTime: null, startCursor: null });
            break;
        case actions_1.ActionType.UPDATE_FPS_LIMIT:
            if (!state.playing)
                newState = Object.assign(Object.assign({}, newState), { fpsLimit: action.payload });
            break;
        case actions_1.ActionType.UPDATE_DURATION:
            if (!state.playing)
                newState = Object.assign(Object.assign({}, newState), { duration: action.payload });
            newState = state;
            break;
        case actions_1.ActionType.CLEAR_FRAMES:
            newState = Object.assign(Object.assign({}, newState), { frames: [], playing: false, cursor: 0, startTime: null, startCursor: null });
            break;
        case actions_1.ActionType.PUSH_FRAMES:
            newState = Object.assign(Object.assign({}, newState), { frames: state.frames.length
                    ? immer_1.produce(state.frames, (draft) => {
                        for (let frame of action.payload) {
                            draft.push(frame);
                        }
                    })
                    : action.payload });
            break;
        case actions_1.ActionType.GET_PREVIOUS_FRAME:
            if (state.cursor > 0)
                newState = Object.assign(Object.assign({}, newState), { cursor: state.cursor - 1 });
            break;
        case actions_1.ActionType.GET_NEXT_FRAME:
            if (state.cursor < state.frames.length - 1)
                newState = Object.assign(Object.assign({}, newState), { cursor: state.cursor + 1 });
            else if (state.playing)
                newState = Object.assign(Object.assign({}, newState), { playing: false, startCursor: null, startTime: null });
            break;
    }
    return newState;
};
