"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createReducer = void 0;
const actions_1 = require("./actions");
exports.createReducer = () => (state, action) => {
    let newState = state;
    switch (action.type) {
        case actions_1.ActionType.PLAY:
            if (!state.playing && state.frames.length) {
                const cursor = state.cursor === state.frames.length - 1 ? 0 : state.cursor;
                newState = Object.assign(Object.assign({}, newState), { cursor, playing: true, startCursor: cursor, startTime: Date.now() });
            }
            break;
        case actions_1.ActionType.PAUSE:
            if (state.playing)
                newState = Object.assign(Object.assign({}, newState), { playing: false, startTime: null, startCursor: null });
            break;
        case actions_1.ActionType.RESET:
            newState = Object.assign(Object.assign({}, newState), { playing: false, cursor: 0, startTime: null, startCursor: null });
            break;
        case actions_1.ActionType.SET_CURSOR:
            if (!state.playing || !state.frames.length)
                break;
            newState = Object.assign(Object.assign({}, newState), { cursor: action.payload });
            if (newState.cursor >= newState.frames.length - 1) {
                newState = state.loop
                    ? Object.assign(Object.assign({}, newState), { playing: true, startTime: Date.now(), startCursor: action.payload % newState.frames.length, cursor: action.payload % newState.frames.length }) : Object.assign(Object.assign({}, newState), { playing: false, startTime: null, startCursor: null, cursor: newState.frames.length - 1 });
            }
            break;
        case actions_1.ActionType.GET_PREVIOUS_FRAME:
            if (!state.playing && state.cursor > 0)
                newState = Object.assign(Object.assign({}, newState), { cursor: state.cursor - 1 });
            break;
        case actions_1.ActionType.GET_NEXT_FRAME:
            if (!state.playing && state.cursor < state.frames.length - 1)
                newState = Object.assign(Object.assign({}, newState), { cursor: (state.cursor + 1) % state.frames.length });
            break;
        case actions_1.ActionType.UPDATE_DURATION:
            if (!state.playing)
                newState = Object.assign(Object.assign({}, newState), { duration: action.payload });
            break;
        case actions_1.ActionType.CLEAR:
            newState = Object.assign(Object.assign({}, newState), { frames: [], playing: false, cursor: 0, startTime: null, startCursor: null });
            break;
        case actions_1.ActionType.LOAD:
            newState = action.payload[2]
                ? Object.assign(Object.assign({}, newState), { frames: action.payload[0], duration: action.payload[1], playing: true, cursor: 0, startTime: Date.now(), startCursor: 0 }) : Object.assign(Object.assign({}, newState), { frames: action.payload[0], duration: action.payload[1], playing: false, cursor: 0, startTime: null, startCursor: null });
            break;
        case actions_1.ActionType.SET_LOOP:
            newState = Object.assign(Object.assign({}, newState), { loop: action.payload });
    }
    return newState;
};
